#
# spec file for package python-openqa_review
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Define just "test" as a package in _multibuild file to distinguish test
# instructions here
%if "test" == ""
%define _test 0
%define name_ext %nil
%else
%define _test 1
%define name_ext -test
%endif

%define pythons python3

%define         short_name openqa_review
%define         binaries openqa-review openqa-review-daily-email openqa-review-sles-ha tumblesle-release openqa-review-functional_yast_concise
%define         oldpython python
Name:           python-%{short_name}%{?name_ext}
Version:        1.30.0
Release:        3.0.2.1.sr20250302
Summary:        A review helper script for openQA
License:        MIT
Source:         python-%{short_name}-%{version}.tar.xz
URL:            https://github.com/os-autoinst/%{short_name}
BuildRequires:  python-rpm-macros
%if 0%{?_test}
BuildRequires:  python3-%{short_name} == %{version}
%else
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
# workaround because of python-configparser not providing the '__init__.py'
# file within site-packages/backports
%if "%{python_flavor}" == "python2"
Requires:       python-backports.ssl_match_hostname
Requires:       python-configparser
%endif
Requires:       python-PyYAML
Requires:       python-beautifulsoup4
Requires:       python-certifi
Requires:       python-humanfriendly
Requires:       python-pika
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-sortedcontainers
Requires(post): update-alternatives
Requires(preun): update-alternatives
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%ifpython2
Obsoletes:      %{oldpython}-%{short_name} < %{version}
%endif

%if 0%{?_test}
%else
%python_subpackages
%endif

%description
A review helper script for openQA. For more details look into the README file.

%prep
%if 0%{?_test}
# workaround to prevent post/install failing assuming this file for whatever
# reason
touch %{_sourcedir}/%{short_name}
%else
%setup -q
# delete shebang of files not in executable path
find %{short_name}/ -name '*.py' -print0 | xargs -0 sed -i '1s/#!.*$//'
%endif

%build
%if 0%{?_test}
openqa-review --help
tumblesle-release --help
%else
%python_build
%endif

%install
%if 0%{?_test}
# disable debug packages in package test to prevent error about missing files
%define debug_package %{nil}
%else
%python_install
rm %{buildroot}/%{python_sitelib}/version.*

for i in %{binaries}; do
    %python_clone -a %{buildroot}%{_bindir}/$i
done
%fdupes %{buildroot}%{_prefix}

%post
%{python_install_alternative %{binaries}}

%preun
%python_uninstall_alternative openqa-review

%files %{python_files}
%defattr(-,root,root,-)
%license LICENSE
%doc README.md
%{python_sitelib}
%python_alternative %{_bindir}/openqa-review
%python_alternative %{_bindir}/openqa-review-sles-ha
%python_alternative %{_bindir}/openqa-review-daily-email
%python_alternative %{_bindir}/openqa-review-functional_yast_concise
%python_alternative %{_bindir}/tumblesle-release

%endif

%changelog
* Tue Mar 11 2025 okurz@suse.com
- Update to version 1.30.0:
  * Add commandline usage from git clone
  * Mention NO_REMINDER_REGEX as additional option to prevent reminders
  * tox: Update tested python versions
  * tox: Add python3.13 which is already in Tumbleweed
  * Apply black suggestions as of 2024-08-01
  * Encode values in URLs
* Tue Sep 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Clean up no longer needed Requires.
* Tue Aug 16 2022 okurz@suse.com
- Update to version 1.30.0:
  * Add command line option for "reopen"
  * Re-open issues when adding reminder comments
  * Fix tests for all Python versions
  * Test expected step in the reminder comment
  * Include test details steps inside the reminder comment
  * Add test to check if the link includes module and step
  * Include expected time until next reminder message
  * Compute the threshold for sending reminder
  * Add extra test case to make codecov happy
  * Add option to disable exponential backoff
* Mon Jun 28 2021 okurz@suse.com
- Update to version 1.25.0:
  * Make link to HTML report variable
  * doc: Add CURL_CA_BUNDLE
  * Improve handling of --filter
  * Add User-Agent header to HTTP requests
  * Fix relative import path for directly called testsuite
  * Remove futurize from tests
  * Update setup.py - remove python2 compactibility stuff
  * Fix handling of softfail bugrefs
  * Issue: Consistently Use self.bugref instead of bugref from arg
* Fri Jun 25 2021 okurz@suse.com
- Update to version 1.24.0:
  * doc: Add CURL_CA_BUNDLE
  * Improve handling of --filter
  * Add User-Agent header to HTTP requests
  * Fix relative import path for directly called testsuite
  * Remove futurize from tests
  * Update setup.py - remove python2 compactibility stuff
  * Remove 'futurize' usage, isnt needed with drop of python2 suppport
  * Use correct shebang for rpm based distributions
* Thu Jun 24 2021 okurz@suse.com
- Update to version 1.23.0:
  * Fix handling of softfail bugrefs
  * Issue: Consistently Use self.bugref instead of bugref from arg
* Thu Jun 24 2021 okurz@suse.com
- Update to version 1.22.0:
  * Also exclude newly introduced "EOL" job groups
  * Specify Loader=yaml.SafeLoader explicitly
* Wed Jun 23 2021 okurz@suse.com
- Update to version 1.21.2:
  * Replace retry loop with Retry from urllib3
* Mon Jun 21 2021 okurz@suse.com
- Update to version 1.21.1:
  * Surface last error from browser.get
* Mon Jun 14 2021 okurz@suse.com
- Update to version 1.21.0:
  * Add option --skip-passed to skip passed reports
  * Update travis CI URLs after migration to travis-ci.com
  * Also include black in flake8 check by plugin
  * Manually reformat some strings for shorter lines
  * Prevent C901 style issue reporting due to misplaced comment
  * Reduce line-length to 120 to be consistent with openQA
  * tox: Execute "fast" black
  * tox: Directly give hints to user what black complains about
  * Integrate "black" formatter into tox
  * Reformat code with black
  * Add python-3.9 to testenv
  * Check python code style with black
  * Disambiguate docs and refer to Python3 explicitly
  * Drop Python 2.7 support from CI and tox
* Fri Mar  5 2021 okurz@suse.com
- Update to version 1.20.4:
  * Change comments to not private when adding comments
  * Fix readout of custom softfail references
  * Adapt parsing of soft-failure details on openQA >= 4.5.1528009330.e68ebe2b-3956-gfac9d6dc2
* Mon Aug  3 2020 okurz@suse.com
- Update to version 1.20.2:
  * Delete unused import json
  * Fix "ValueError: Expecting ',' delimiter: line 1..." when trying to parse soft-fail details
* Fri Jul 24 2020 okurz@suse.com
- Update to version 1.20.1:
  * Read text data from details JSON if present
* Wed May 27 2020 okurz@suse.com
- Update to version 1.20.0:
  * Fix 'E741 ambiguous variable name' in tests
  * Adapt parsing of soft-failure details on openQA >= 4.5.1528009330.e68ebe2b-3454-gd19c50d6b
* Sat May  9 2020 Oliver Kurz <okurz@suse.com>
- Update test-package to use python3 variant also to fix Factory build tests
* Tue May  5 2020 okurz@suse.com
- Update to version 1.19.0:
  * Adapt parsing of soft-failure details to openQA >= 4.5.1528009330.e68ebe2b-3120-g92a4d55ef
  * Adapt soft-fail parsing to new details format produced by openQA
* Mon Mar  9 2020 okurz@suse.com
- Update to version 1.17.0:
  * Add python 3.8 to testing as in openSUSE Tumbleweed
  * Add error message for failed ssl connections
  * Simplify generation code of 'skipped' section
* Mon Jan 27 2020 okurz@suse.com
- Update to version 1.16.0:
  * Fix error on repeated test modules when reading out details from soft-fail bugrefs
  * Fix failed assertion on build with only incompletes
  * Rely only on POSIX 'command -v' rather than non-standard which
  * In the bug reminder comment explain options to prevent further reminders
* Mon Sep 30 2019 okurz@suse.com
- Update to version 1.15.0:
  * Fix new style check Q003 about quotes
  * Update tested python versions to 3.6 (Leap), 3.7 (Tumbleweed)
  * Use consistent single-tick default quoting style
  * Also skip output of "Skipped tests" when option for skipping empty is enabled
  * Fix superfluous blank line in output after "Skipped tests"
  * Fix deprecation warning about "log.warn"
  * Delete superfluous blank line
  * Use same text format for "Skipped tests" as for "issues" and "bugs"
  * Fix all style issues introduced by PR #119 and #121
  * Fix tests for pika 1.0
  * Skipped tests includes links
  * Fix output of 'type' for debugging
  * Another try to fix ASCII encoding errors in python2
  * Add testdata for unicode signs *everywhere*
  * Fix sporadic ASCII encoding errors in python2 on complete report
  * openqa-review-daily-email: Save time by skipping report-links
  * openqa-review-daily-email: Allow to override the temporary output directory
  * Fix style for flake 3.7.5
* Sat Dec 22 2018 okurz@suse.com
- Update to version 1.14.1:
  * Fix path to openqa-review-functional_yast_conice
  * openqa-review-functional_yast_concise: Adapt job group name to recent changes on OSD
  * Use version compare algo to compare builds
  * Fix python style checks for new flake8
  * Adapt upstream target to os-autoinst
  * Add test for multi-version build_compare_urls
  * Use 'key' instead of 'build' for comparison
  * .travis.yml: Try to fix repeated pypi deployment tries in all python versions
  * dashboard: Provide explanation on top as requested
  * dashboard: Try to discover the template file from current dir
* Mon Dec 10 2018 okurz@suse.com
- Adapt upstream target to os-autoinst
* Wed Nov 14 2018 okurz@suse.com
- Update to version 1.13.1:
  * dashboard: Provide explanation on top as requested
  * dashboard: Try to discover the template file from current dir
  * dashboard: Replace the fake openQA footer with an explanation of the report content
  * Handle connection error while sending POST
* Sat Sep 22 2018 okurz@suse.com
- Update to version 1.13.0:
  * Delete obsolete warning about build number format
  * Fix non-ascii encoding problems in the whole generated report
  * Add request retry on HTTP error 503
  * Add tests for urls formatting using markdown
  * Format all urls in softfail message using markdown
* Wed Jul 25 2018 okurz@suse.com
- Update to version 1.12.1:
  * Fix problem introduced in 4189852 parsing the URL parameter
  * Fix non-ascii characters in external references
  * Fix report_link for pre-4.6
  * Add backwards-compatible support for pre-4.6 openQA
* Wed Jul 11 2018 okurz@suse.com
- Update to version 1.11.0:
  * Fix workaround bugref not detected on string after bugref
  * tox.ini: Specify pika as test dependency for tox environment "cov"
  * Adapt script to the openQA layout changes
  * Fix report filter for issues with not valid bugref
  * Test filter report  with not valid bugref
  * Fix reminder comment when issue type is not valid
  * Test reminder comment when issue type is not valid
  * Fix report generation for issues without bugid
  * Test if issue without bugid processed correctly
  * Add request retry on HTTP error 504
  * Add soft-fails without bugref to openqa report
  * Add test data for softfailed test without bugref
  * Add hint for custom CA store locations
  * Process poo#0/boo#0/bsc#0 ticket labels
- Switch package build to obs_scm service
* Wed May  9 2018 okurz@suse.com
- Update to version 1.10.1:
  * Fix parsing of failedmodules for bootstrap4
  * Align travis python test versions to tox.ini
* Wed May  2 2018 tchvatal@suse.com
- Move install call on proper location
* Fri Feb  9 2018 okurz@suse.com
- Update to version 1.10.0:
  * Add helper script for SLE15 functional+autoyast concise report
  * Reference new review wrapper script in setup.py
* Thu Feb  8 2018 okurz@suse.com
- Adapt license file location according to new suggestion around %%license
* Wed Feb  7 2018 okurz@suse.com
- Update to version 1.9.0:
  * openqa-review-daily-email: Fix passing of additional options with whitespace
  * Add two options to further abbreviate condensed reports
  * Include difference in numbers on verbosity level above 3
  * Correct optional code for updating reference reports
  * Encode severity together with priority for ticket references
  * Mark closed tickets as red
  * setup.py: Fix flake8 reported style issues with explicit except
  * setup.py: Catch errors as reported on no version.py from OBS build
  * setup.py: python2 backward cruft/craft
* Fri Jan 19 2018 okurz@suse.com
- Update to version 1.8.3:
  * Add 'bgo' bugref
  * Handle unknown bugtrackers gracefully
* Wed Dec 20 2017 okurz@suse.com
- Update to version 1.8.2:
  * browser: Status code is not always available on error
  * setup.py: Correct name of tests_require
  * Project is no production stable
  * Only require separate configparser for python2
  * Fix require of configparser for python3
* Sun Dec 17 2017 okurz@suse.com
- Provide singlespec file with update-alternatives including self-test
  * Better multibuild-evaluation with valid syntax allowing local use of
    '-M test'
  * Complete runtime requirements including "python-setuptools"
  * Complete set of scripts for both python2 and python3
  * Package self-test for all repositories and python2/python3
* Sat Dec 16 2017 okurz@suse.com
- Update to version 1.8.0:
  * Provide job references in failed soft-fail parsing
  * Add review wrapper script for 'functional' group on openqa.suse.de
  * Handle disconnects by remote end on API get gracefully
* Thu Sep 21 2017 okurz@suse.com
- Update version to support more recent openQA web structure (boo#1059661)
* Wed Sep 20 2017 okurz@suse.com
- Update to version 1.7.5:
  * Add preliminary tumblesle release script for SLE 15
  * Support multi-distri job groups with openQA#037ffd33
* Sat Aug 26 2017 okurz@suse.com
- Update to version 1.7.4:
  * Fix error 401 on redmine after server side ngingx update
  * Ignore cscope.out
  * Fix whitespace as reported by flake8
  * Fix handling of dotted build numbers parsing from comments
* Mon Jul 24 2017 okurz@suse.com
- Update to version 1.7.2:
  * Extend soft-fail issue tracker support
* Sun Jul 23 2017 okurz@suse.com
- Update to version 1.7.1:
  * Also parse soft-fail needles
* Fri Jul 21 2017 okurz@suse.com
- Update to version 1.7.0:
  * Skip error on writing reminder comments gracefully
  * Get bugref details for softfails as well
  * Split big 'bugrefs' test into more subtests
  * Remove not used variables (#70)
* Sun Jul 16 2017 okurz@suse.com
- Update to version 1.6.8:
  * .gitignore: Also exclude pycharm
  * Extract reading reference report in test for simpler ref report updating
  * Fix 'interesting_states' not really filtering out STABLE results
  * Use lowercase 'todo' dict key for easier distinction from TODO in source code comments
  * Tiny duplication removal in tox.ini
  * Fix potential wrong import of not-backported configparser within py27 tests
  * Delete again configparser2 reference which is another module
  * Simplify handling of results/results_by_bugref dicts
  * Delete obsolete test data entry for soft-failed with failed modules
  * Use newer python3.6 as in openSUSE Tumbleweed for testing
  * Also include 'IMPROVED' in soft fail states
  * Simplify 'soft-fail' calculation within IssueEntry
  * Delete some redundant soft-fails for easier testing
* Wed Jun 14 2017 okurz@suse.com
- Update to version 1.6.6:
  * Add CLOSED to issue states for non-open tickets (#61)
  * Fix broken HTML
  * Fix doc-strings issue D401, not imperative mood
  * Retry download in case of 502
* Wed Mar 15 2017 okurz@suse.com
- Update to version 1.6.4:
  * Remove unused webtests (#58)
  * dashboard: Prevent duplicate reminder comments
  * Extend review-daily-email for use with opensuse.org
  * Install 'openqa-review-daily-email' script
* Wed Mar 15 2017 okurz@suse.com
- Include new binary 'openqa-review-daily-email'
* Wed Mar  8 2017 okurz@suse.com
- Update to version 1.6.2:
  * dashboard: Correct exclude regex syntax after live test
* Wed Mar  8 2017 okurz@suse.com
- Update to version 1.6.1:
  * Add option to exclude job groups by regex
  * Fix flake8 checks in tumblesle_release
  * Ignore obsolete released and development job groups in dashboard report
* Fri Mar  3 2017 opensuse-packaging@opensuse.org
- Update to version 1.5.2:
  * tumblesle_release: Add optional AMQP authentication
  * Add CII badge after review
  * Replace obsolete gitlab with github reference
  * Fix version file parsing when there is no git tag
  * tumblesle-release: Retry on AMQP connection lost
* Fri Mar  3 2017 okurz@suse.com
- Fix import error on backports.configparser by workaround (boo#1025589)
* Tue Feb 14 2017 opensuse-packaging@opensuse.org
- Update to version 1.5.1:
  * Fix openqa_review_osd_daily_email running in dry-run by default
* Mon Feb  6 2017 opensuse-packaging@opensuse.org
- Update to version 1.5.0:
  * Post issue reminder comments from daily review script
  * tumblesle_release: Add AMQP notification support for 'suse_msg'
  * tumblesle_release: Add documentation for AMQP notifications
  * tumblesle_release: Prevent spammy repetition of AMQP notifications
  * Get rid of duplicate update_jekyll
  * More tumblesle notifications
  * Fix tumblesle script not checking for new builds / updated job results
  * Make tumblesle_release notification connection more resilient
  * tumblesle_release: Only store in notify_seen on success
  * Recommend safer installation proposals
  * Ensure valid python certificates with certifi
  * Be more specific about the error when file not found in cache
  * Ensure all data is cached on save in openqa_review_osd_daily_email
* Thu Jan 26 2017 okurz@suse.com
- Correct missing package content for update to 1.4.1
* Fri Jan 20 2017 opensuse-packaging@opensuse.org
- Update to version 1.4.1:
  * Ignore builds which have an actual empty build value
* Fri Jan 20 2017 opensuse-packaging@opensuse.org
- Update to version 1.4.0:
  * Add tumblesle example scripts
  * Use index.json to get job groups (#36)
  * Prepare for wellformed json (#38)
  * Fix #41: Handle broken bugrefs gracefully (#42)
  * Fix for parent groups: Use API to get job_groups (#43)
  * Use JSON version of group_overview (#44)
  * TODO: Add entry about configparser travis error
  * Ensure configparser is available for py2+3
  * Fix py27 errors only observable on travis
  * Handle job groups with builds not having any 'done' jobs at all
  * Try to get distri/version for each build (#47)
  * Ensure proper URL concatenation on py2 for bug details retrieval
  * Show parent group in report (#48)
  * Add tumblesle helper script for 12sp3
  * Add update_jekyll for tumblesle release
  * Use blank build value without version prefix (#51)
  * Comment on old bugs with new failed test url (#50)
  * Fix flake8 reported issues after 48fb659
  * Fix parsing of job groups after openQA#9b50b22
  * Run all envs on travis
  * Add command line option for '--min-days-unchanged' for reminder comments
* Tue Oct 18 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.2:
  * Fix crash on new-style 'empty builds'
* Tue Oct 18 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.1:
  * Debug output for 'not enough builds'
  * Get rid of possibly already covered exception handling
  * bin: Mark script as executable
  * dashboard: Customize html header content, e.g. title
  * tumblesle_release: Regard 'softfailed' in newer versions of openQA as passed
* Thu Oct  6 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.1:
  * tests: Correct test files for 'after_61b4db60'
  * Prevent "no builds" found for weird combination of python packages for some users
* Thu Sep 29 2016 opensuse-packaging@opensuse.org
- Update to version 1.3.0:
  * report_links: Make 'latest' a link in markdown format
  * wip -- add bug report links, also for progress, for later
  * TODO: correct indendation of some entries
  * TODO: Remove implemented bug reporting links
  * browser: Support saving pages with unicode content in python2
  * issue_report_link: Support non-digit builds
  * issue_report_link: Handle non-existing product mapping option gracefully
  * Allow filtering for closed / unassigned bugs
  * TODO: Add some ideas
  * Add dashboard generation script
  * Store dashboard file at common "bin" location
  * Delete unnecessary bootstrap.js and font files
  * Add LICENSE.GPL-2 for files under dashboard_files/
  * dashboard: Use robust 'sh -e' shebang
  * Add bin/openqa_review_osd_daily_email script
  * dashboard: Make all variables options with defaults
  * dashboard: Replace three-step sed replace by proper template replace
  * dashboard: Customize logo with a big 'R' on top for 'review'
  * Merge 'dashboard' and 'openqa_review_osd_daily_email'
  * issue_report_link: Fix unsupported failures without failed modules
  * TODO: Mark 'use test verbosity for existing' as fixed
  * Do not fail when there are no closed/unass bugs (#28)
  * Fix #21: Put hr to own line and use md syntax (#29)
  * Make hr between products on dashboard page thicker (#31)
  * Fix ") in issue subject breaking markdown (#30)
  * Support new-style progress bars of openQA
* Wed Sep 21 2016 opensuse-packaging@opensuse.org
- Update to version 1.2.0:
  * Display ticket priority (#25)
  * Show __doc__ as port of help
  * Add links to verbose reports to directly report bugs
  * Use host specific issue tracker product mapping
  * Ensure multiple missing archs are sorted
  * Add more information to bug report links
* Tue Sep 20 2016 opensuse-packaging@opensuse.org
- Update to version 1.1.0:
  * Get objects up into the main function (#22)
  * Fix arch matching (#23)
  * Treat incomplete->failed as new failures
* Mon Sep 19 2016 opensuse-packaging@opensuse.org
- Update to version 1.0.0:
  * Simplify script usage (#13)
  * Add Browser cache (#15)
  * Be more strict about bugrefs read on openQA webpages
  * Use Objects to handle Issues and ArchReport
  * Add .swp files to .gitignore
  * Fix soft failed: Use new 'result_softfailed' str
  * TODO: Add idea about bug reporting links
  * Add ArchReports and IssueEntry obj (#19)
  * '-r' and '-T' are not mutually exclusive anymore
  * Get objects up into the main function (#22)
* Tue Sep 13 2016 opensuse-packaging@opensuse.org
- Update to version 0.8.1:
  * Fix 'missing architectures' entry not yielding proper table row
  * Fix D403 style issues
  * Prevent flake8 check running on existing .tox dir
  * Ensure proper python2+3 testing on different distributions
  * TODO: DONE "Using labels …" with commit fd1b373
  * TODO: DONE "package for openSUSE"
* Mon Sep 12 2016 opensuse-packaging@opensuse.org
- Update to version 0.8.0:
  * Read Bugzilla issue status & subject (#8)
  * Fix config parsing for python2 (#9)
  * Fix insecure ssl warning (#10)
  * TODO: Add reference to mass bug filing tool
  * Let --query-issue-status" arg implie --bugrefs (#11)
  * Extract Browser into module
  * Extract report generator object for 'new issue'
  * Use absolute imports for python2
* Thu Aug 25 2016 opensuse-packaging@opensuse.org
- Update to version 0.7.1:
  * .travis.yml: Add pypi deploy commands
  * Correct name in setup.py to 'openqa_review'
  * Add reference for pypi deploy to .travis.yml
  * Accept 'not enough finished builds' as expected behaviour
  * Prevent inactive job groups showing up in openQA >= 4.4
  * Add wrapper script for SLES/HA review
  * Correct markdown syntax of code segments
  * Handle download errors graciously
  * Correct log message for saving files in Browser
  * Fix 'KeyError TODO' with builds having only bugref'd jobs
* Sun Jan 24 2016 okurz@suse.de
- initial package
